package envoy.data;

import java.util.ArrayList;
import java.util.List;
import java.util.StringJoiner;

/**
 * Project: <strong>envoy-common</strong><br>
 * File: <strong>Group.java</strong><br>
 * Created: <strong>24 Mar 2020</strong><br>
 *
 * @author Leon Hofmeister
 * @since Envoy Common v0.1-beta
 */
public class Group extends Contact {

	// TODO add admins
	private final List<Long> memberIDs;

	private static final long serialVersionUID = 0L;

	/**
	 * Creates a new instance of a {@link Group}.
	 *
	 * @param id   the ID of this group
	 * @param name the name of this group
	 * @since Envoy Common v0.1-beta
	 */
	public Group(long id, String name) { this(id, name, new ArrayList<>()); }

	/**
	 * Creates a new instance of a {@link Group}.
	 *
	 * @param id        the ID of this group
	 * @param name      the name of this group
	 * @param memberIDs the IDs of all members that should be preinitialized
	 * @since Envoy Common v0.1-beta
	 */
	public Group(long id, String name, List<Long> memberIDs) {
		super(id, name);
		this.memberIDs = memberIDs;
	}

	/**
	 * @return the IDs of all members of this group
	 * @since Envoy Common v0.1-beta
	 */
	public List<Long> getMemberIDs() { return memberIDs; }

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {
		var joiner = new StringJoiner(",", "Group[id=", "]");
		joiner.add("id=" + getID());
		joiner.add("name=" + getName());
		joiner.add("members=" + getMemberIDs().size());
		return joiner.toString();
	}
}
